@@ -308,7 +308,8 @@ def ChoquetMob(x, Mob, env):
 def ConstructLambdaMeasure(singletons, env):
     trace( "void py_ConstructLambdaMeasure(double* singletons, double* out_lambdax, double* out_v, struct fm_env* env)")
     psingletonsnp, psingletons = convert_py_float_to_cffi( singletons)
-    pout_lambdaxnp, pout_lambdax = create_float_zeros_as_CFFI_double( env.m)
+    # lambda is an array of size 1 
+    pout_lambdaxnp, pout_lambdax = create_float_zeros_as_CFFI_double( 1)
     pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
     fm.py_ConstructLambdaMeasure( psingletons, pout_lambdax, pout_v, env)
     return pout_lambdaxnp, pout_vnp
@@ -319,7 +320,8 @@ def ConstructLambdaMeasure(singletons, env):
 def ConstructLambdaMeasureMob(singletons, env):
     trace( "void py_ConstructLambdaMeasureMob(double* singletons, double* out_lambdax, double* out_Mob, struct fm_env* env)")
     psingletonsnp, psingletons = convert_py_float_to_cffi( singletons)
-    pout_lambdaxnp, pout_lambdax = create_float_zeros_as_CFFI_double( env.m)
+    # lambda is an array of size 1 
+    pout_lambdaxnp, pout_lambdax = create_float_zeros_as_CFFI_double( 1)
     pout_Mobnp, pout_Mob = create_float_zeros_as_CFFI_double( env.m)
     fm.py_ConstructLambdaMeasureMob( psingletons, pout_lambdax, pout_Mob, env)
     return pout_lambdaxnp, pout_Mobnp
@@ -514,34 +516,38 @@ def fittingWAM(datanum, env, dataset = None):
     return pout_vnp, dataset
 
 
+
 # Generated python wrapper for:
-#    void py_Interaction(double* out_Mob, double* v, struct fm_env* env)
-def Interaction(v, env):
-    trace( "void py_Interaction(double* out_Mob, double* v, struct fm_env* env)")
-    pout_Mobnp, pout_Mob = create_float_zeros_as_CFFI_double( env.m)
-    pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_Interaction( pout_Mob, pv, env)
-    return pout_Mobnp
+#    void py_Interaction(double* Mob, double* out_v, struct fm_env* env)
+def Interaction(Mob, env):
+    trace( "void py_Interaction(double* Mob, double* out_v, struct fm_env* env)")
+    pMobnp, pMob = convert_py_float_to_cffi( Mob)
+    length = len( Mob)
+    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( length)
+    fm.py_Interaction( pMob, pout_v, env)
+    return pout_vnp
 
 
 # Generated python wrapper for:
-#    void py_InteractionB(double* out_Mob, double* v, struct fm_env* env)
-def InteractionB(v, env):
-    trace( "void py_InteractionB(double* out_Mob, double* v, struct fm_env* env)")
-    pout_Mobnp, pout_Mob = create_float_zeros_as_CFFI_double( env.m)
-    pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_InteractionB( pout_Mob, pv, env)
-    return pout_Mobnp
+#    void py_InteractionB(double* Mob, double* out_v, struct fm_env* env)
+def InteractionB(Mob, env):
+    trace( "void py_InteractionB(double* Mob, double* out_v, struct fm_env* env)")
+    pMobnp, pMob = convert_py_float_to_cffi( Mob)
+    length = len( Mob)
+    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( length)
+    fm.py_InteractionB( pMob, pout_v, env)
+    return pout_vnp
 
 
 # Generated python wrapper for:
-#    void py_InteractionMob(double* out_Mob, double* v, struct fm_env* env)
-def InteractionMob(v, env):
-    trace( "void py_InteractionMob(double* out_Mob, double* v, struct fm_env* env)")
-    pout_Mobnp, pout_Mob = create_float_zeros_as_CFFI_double( env.m)
-    pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_InteractionMob( pout_Mob, pv, env)
-    return pout_Mobnp
+#    void py_InteractionMob(double* Mob, double* out_v, struct fm_env* env)
+def InteractionMob(Mob, env):
+    trace( "void py_InteractionMob(double* Mob, double* out_v, struct fm_env* env)")
+    pMobnp, pMob = convert_py_float_to_cffi( Mob)
+    length = len( Mob)
+    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( length)
+    fm.py_InteractionMob( pMob, pout_v, env)
+    return pout_vnp
 
 
 # Generated python wrapper for:
@@ -549,11 +555,11 @@ def InteractionMob(v, env):
 def InteractionBMob(Mob, env):
     trace( "void py_InteractionBMob(double* Mob, double* out_v, struct fm_env* env)")
     pMobnp, pMob = convert_py_float_to_cffi( Mob)
-    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( env.m)
+    length = len( Mob)
+    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( length)
     fm.py_InteractionBMob( pMob, pout_v, env)
     return pout_vnp
 
-
 # Generated python wrapper for:
 #    void py_BipartitionShapleyIndex(double* v, double* out_w, struct fm_env* env)
 def BipartitionShapleyIndex(v, env):
@@ -835,7 +841,7 @@ def dualMobKadd(k, src, env):
     pout_destnp, pout_dest = create_float_zeros_as_CFFI_double( env.m)
     length = fm.py_fm_arraysize( env.n, k, env)
     fm.py_dualMobKadd( env.m, length, k, psrc, pout_dest, env)
-    return pout_destnp
+    return pout_destnp, length
 
 
 # Generated python wrapper for:
@@ -880,39 +886,56 @@ def fm_arraysize(n, kint, env):
 #    int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* out_vv, struct fm_env* env)
 def generate_fm_minplus(num, n, kint, markov, option, K, env):
     trace( "int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* out_vv, struct fm_env* env)")
-    len = fm.py_fm_arraysize(n, kint, env) * n
-    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( len)
+    length = fm.py_fm_arraysize(n, kint, env)
+    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( num * length)
     yy = fm.py_generate_fm_minplus( num, n, kint, markov, option, K, pout_vv, env)
-    return yy, pout_vvnp
+    return yy, pout_vvnp, length
 
 
 # Generated python wrapper for:
 #    int py_generate_fm_2additive_convex(int num, int n,  double* out_vv)
 def generate_fm_2additive_convex(num, n):
     trace( "int py_generate_fm_2additive_convex(int num, int n,  double* vv)")
-    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( n)
+    length = num * n * n
+    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( length)
     yy = fm.py_generate_fm_2additive_convex( num, n, pout_vv)
-    return yy, pout_vvnp
+    return yy, pout_vvnp, length
 
 
 # Generated python wrapper for:
 #    int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* out_vv)
 def generate_fm_2additive_convex_withsomeindependent(num, n):
     trace( "int py_generate_fm_2additive_convex_withsomeindependent(int num, int n, double* vv)")
-    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( n)
+    length = num * n * n
+    pout_vvnp, pout_vv = create_float_zeros_as_CFFI_double( length)
     yy = fm.py_generate_fm_2additive_convex_withsomeindependent( num, n, pout_vv)
-    return yy, pout_vvnp
+    return yy, pout_vvnp, length
 
 
 # Generated python wrapper for:
 #    void py_prepare_fm_sparse(int n, int tupsize, int* tuples, struct fm_env_sparse* out_env)
-def prepare_fm_sparse(n, tupsize, tuples, out_env):
-    trace( "void py_prepare_fm_sparse(int n, int tupsize, int* tuples, struct fm_env_sparse* out_env)")
-    ptuplesnp, ptuples = convert_py_int_to_cffi( tuples)
-    fm.py_prepare_fm_sparse( n, tupsize, ptuples, out_env)
-    return out_env
+def prepare_fm_sparse( n, tupsize):
+    try:
+        trace( "void py_prepare_fm_sparse(int n, int tupsize, int* tuples, struct fm_env_sparse* out_env)")
+        # if tupsize == 0: tupsize = 1
+        ptuplesnp, ptuples = create_intc_zeros_as_CFFI_int( tupsize)
+        pout_env_sparse = ffi.new( "struct fm_env_sparse *")
+        fm.py_prepare_fm_sparse( n, tupsize, ptuples, pout_env_sparse)
+        return pout_env_sparse
+    except ValueError:
+        raise
 
 
+# Generated python wrapper for:
+#    void py_free_fm_sparse( struct fm_env_sparse* env)
+def free_fm_sparse(env_sparse):
+    try:
+        trace( "void py_free_fm_sparse( struct fm_env_sparse* env)")
+        if( env_sparse == None): raise ValueError( "Env sparse not initialised") 
+        fm.py_free_fm_sparse( env_sparse)
+    except ValueError:
+        raise
+
 # Generated python wrapper for:
 #    int py_tuple_cardinality_sparse(int i, struct fm_env_sparse* env)
 def tuple_cardinality_sparse(i, env):
