@@ -158,13 +158,17 @@ extern "C" {
 // todo: add cases i==3,4 explicit formulas
 inline int_64 choose(int i, int n, struct fm_env* env)
 {
-	if (i == 1) return n;
-	if (i == 2) return (int_64)(n*(n - 1)) / 2;
-	if (i == 3) return (int_64)(n*(n - 1)*(n - 2)) / 6;
-	if (i == 4) return (int_64)(n*(n - 1)*(n - 2)*(n - 3)) / 24;
-	if (i == 5) return (int_64)(n*(n - 1)*(n - 2)*(n - 3)*(n - 4)) / 120;
+	 if (i == 1) return n;
+    if (i == 2) return (int_64)(n*(n - 1)) / 2;
+    if (i == 3) return (int_64)(n*(n - 1)*(n - 2)) / 6;
+    if (i == 4) return (int_64)(n*(n - 1)*(n - 2)*(n - 3)) / 24;
+    if (i == 5) return (int_64)(n*(n - 1)*(n - 2)*(n - 3)*(n - 4)) / 120;
+    if (i == 6) return (int_64)(n*(n - 1)*(n - 2)*(n - 3)*(n - 4)*(n - 5)) / 120 / 6;
+    if (i == 7) return (int_64)(n*(n - 1)*(n - 2)*(n - 3)*(n - 4)*(n - 5)*(n - 6)) / 120 / 42;
+    if (i == 8) return (int_64)(n*(n - 1)*(n - 2)*(n - 3)*(n - 4)*(n - 5)*(n - 6)*(n - 7)) / 120 / 42 / 8;
+    if (i == 9) return (int_64)(n*(n - 1)*(n - 2)*(n - 3)*(n - 4)*(n - 5)*(n - 6)*(n - 7)*(n - 8)) / 120 / 42 / 72;
 
-	return (int_64)(env->factorials[n] / env->factorials[i] / env->factorials[n - i]);
+    return (int_64)(env->factorials[n] / env->factorials[i] / env->factorials[n - i]);
 }
 
 #ifdef PYTHON_
@@ -2183,6 +2187,8 @@ LIBEXP int py_generate_fm_2additive_convex_withsomeindependent(int num, int n,
 }
 
 
+
+
 /*
 Sparse representation of k-additive capacities. Thre representation is in the form of singletons, pairs and tuples with nonzero values, stored and indexed in the respective
 arrays (see above in this file)
@@ -2191,12 +2197,26 @@ arrays (see above in this file)
 
  It is used to allocate storage and later populate these values
 */
+SparseFM::SparseFM() {}
+SparseFM::SparseFM( struct  fm_env_sparse* penv): 
+	n(penv->n),
+    m_singletons( penv->m_singletons, penv->m_singletons + penv->n),
+    m_pairs( penv->m_pairs, penv->m_pairs + penv->n),
+    m_tuples( penv->m_tuples, penv->m_tuples + penv->n),
+    m_pair_index( penv->m_pair_index, penv->m_pair_index + penv->n),
+    m_tuple_start( penv->m_tuple_start, penv->m_tuple_start + penv->n),
+    m_tuple_content( penv->m_tuple_content, penv->m_tuple_content + penv->n) {}
+
 LIBEXP void py_prepare_fm_sparse( int n, int tupsize, int* tuples, struct fm_env_sparse* env)
 {
-	 Prepare_FM_sparse0(n, tupsize, tuples, (SparseFM*)env);
+	SparseFM* psFM = new SparseFM( env); 
+	Prepare_FM_sparse0(n, tupsize, tuples, psFM);
+	env->m_sparce_fm = psFM;
+	// Prepare_FM_sparse0(n, tupsize, tuples, (SparseFM*)env);
 }
 LIBEXP void py_free_fm_sparse(struct fm_env_sparse* env) {
 	Free_FM_sparse((SparseFM*)env);
+	delete( (SparseFM*)env->m_sparce_fm);
 }
 
 /*  Returns the cardinality of the tuple numbered i in the list of tuples */
