@@ -203,7 +203,6 @@ x = pyw.BanzhafMob(Mob, env)
 print( "Mob: ", Mob)
 print( "x: ", x)
 
-
 # Test wrapper for:
 #    double py_ChoquetMob(double* x, double* Mob, struct fm_env* env)
 x =[0.6,0.3,0.8]
@@ -220,7 +219,6 @@ lambdax, v = pyw.ConstructLambdaMeasure(singletons, env)
 print( "singletons: ", singletons)
 print( "lambdax, v: ", lambdax, v)
 
-
 # Test wrapper for:
 #    void py_ConstructLambdaMeasureMob(double* singletons, double* out_lambdax, double* out_Mob, struct fm_env* env)
 singletons = [0, 0.3, 0.5]
@@ -228,7 +226,6 @@ lambdax, Mob = pyw.ConstructLambdaMeasureMob(singletons, env)
 print( "singletons: ", singletons)
 print( "lambdax, Mob: ", lambdax, Mob)
 
-
 # Test wrapper for:
 #    void py_dualm(double* v, double* out_w, struct fm_env* env)
 v =[0,0.3,0.5,0.6,0.4,0.8,0.7,1]
@@ -294,7 +291,7 @@ print( "res: ", res)
 #    void py_FuzzyMeasureFitLPKinteractive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
 datanum = 10
 additive = 2
-K = [0.5]
+K = 0.5
 v, dataset = pyw.FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
@@ -302,11 +299,12 @@ print( "K: ", K)
 print( "dataset: ", dataset)
 print( "v: ", v)
 
+
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLPKinteractiveMaxChains(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K)
 datanum = 10
 additive = 2
-K = [0.5]
+K = 0.5
 v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
@@ -318,7 +316,7 @@ print( "v: ", v)
 #    void py_FuzzyMeasureFitLPKinteractiveAutoK(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters)
 datanum = 10
 additive = 2
-K = [0.5]
+K = 0.5
 maxiters = [100]
 v, dataset = pyw.FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None)
 print( "datanum: ", datanum)
@@ -332,7 +330,7 @@ print( "v: ", v)
 #    void py_FuzzyMeasureFitLPKinteractiveMarginal(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int submod)
 datanum = 10
 additive = 2
-K = [0.5]
+K = 0.5
 submod = 1
 v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env,  K, submod, dataset = None)
 print( "datanum: ", datanum)
@@ -346,7 +344,7 @@ print( "v: ", v)
 #    void py_FuzzyMeasureFitLPKinteractiveMarginalMaxChain(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, double* K, int* maxiters, int submod)
 datanum = 10
 additive = 2
-K = [0.5]
+K = 0.5
 submod = 1
 v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None)
 print( "datanum: ", datanum)
@@ -356,7 +354,6 @@ print( "K: ", K)
 print( "dataset: ", dataset)
 print( "v: ", v)
 
-
 # Test wrapper for:
 #    void py_FuzzyMeasureFitLP(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset, int* options, double* indexlow, double* indexhihg, int* option1, double* orness)
 datanum = 10
@@ -416,33 +413,40 @@ print( "datanum: ", datanum)
 print( "dataset: ", dataset)
 print( "v: ", v)
 
-# Test wrapper for:
-#    void py_Interaction(double* out_Mob, double* v, struct fm_env* env)
-v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-# w = pyw.Interaction(v, env)
-print( "v: ", v)
-print( "w: ", w)
+
+
+pyw.fm_free( env)
+n = 3
+env = pyw.fm_init( n)
 
 # Test wrapper for:
-#    void py_InteractionB(double* out_Mob, double* v, struct fm_env* env)
-v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-# w = pyw.InteractionB(v, env)
+#    void py_Interaction(double* Mob, double* out_v, struct fm_env* env)
+Mob = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
+v = pyw.Interaction(Mob, env)
+print( "Mob: ", Mob)
 print( "v: ", v)
-print( "w: ", w)
 
 # Test wrapper for:
-#    void py_InteractionMob(double* out_Mob, double* v, struct fm_env* env)
-v = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-# w = pyw.InteractionMob(v, env)
+#    void py_InteractionB(double* Mob, double* out_v, struct fm_env* env)
+Mob = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
+v = pyw.InteractionB(Mob, env)
+print( "Mob: ", Mob)
+print( "v: ", v)
+
+# Test wrapper for:
+#    void py_InteractionMob(double* Mob, double* out_v, struct fm_env* env)
+Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
+v = pyw.InteractionMob(Mob, env)
+print( "Mob: ", Mob)
 print( "v: ", v)
-print( "w: ", w)
 
 # Test wrapper for:
 #    void py_InteractionBMob(double* Mob, double* out_v, struct fm_env* env)
-v = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-# w = pyw.InteractionBMob(v, env)
+Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
+v = pyw.InteractionBMob(Mob, env)
+print( "Mob: ", Mob)
 print( "v: ", v)
-print( "w: ", w)
+
 
 # Test wrapper for:
 #    void py_BipartitionShapleyIndex(double* v, double* out_w, struct fm_env* env)
@@ -498,7 +502,6 @@ print( "v: ", v)
 print( "k: ", k)
 print( "w: ", w)
 
-
 # Test wrapper for:
 #    int py_IsMeasureBalanced(double* v, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
@@ -520,7 +523,6 @@ is_measure = pyw.IsMeasureSubadditive(v, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
-
 # Test wrapper for:
 #    int py_IsMeasureSubmodular(double* v, struct fm_env* env)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1, -0.2, 0.1]
@@ -652,15 +654,16 @@ print( "v: ", v)
 #    void py_dualMobKadd(int k, double* src, double* out_dest, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
 kadd = 2
-dual = pyw.dualMobKadd(kadd, Mob, env)
+dual, length = pyw.dualMobKadd(kadd, Mob, env)
 print( "Mob: ", Mob)
 print( "kadd: ", kadd)
+print( "length of output: ", length)
 print( "dual: ", dual)
 
 # Test wrapper for:
 #    void py_Shapley2addMob(double* v, double* out_x, int n)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1]
-n = len(v)
+n = len( v)
 shapley = pyw.Shapley2addMob( v, n)
 print( "v: ", v)
 print( "n: ", n)
@@ -704,16 +707,18 @@ kint = 3
 markov = 1000
 option = 0
 K = 0.7
-array_size = 0
+ret_code = 0
+length = 0
 vv = []
-# array_size, vv = pyw.generate_fm_minplus(num, n, kint, markov, option, K, env)
+ret_code, vv, length = pyw.generate_fm_minplus(num, n, kint, markov, option, K, env)
 print( "num: ", num)
 print( "n: ", n)
 print( "kint: ", kint)
 print( "markov: ", markov)
 print( "option: ", option)
 print( "K: ", K)
-print( "array_size: ", array_size)
+print( "ret_code: ", ret_code)
+print( "length of output: ", length)
 print( "vv: ", vv)
 
 # Test wrapper for:
@@ -721,10 +726,13 @@ print( "vv: ", vv)
 # not documented in R or Python user guide
 num = 10
 n = 6
-# array_size, vv = pyw.generate_fm_2additive_convex(num, n)
+ret_code = 0
+length = 0
+ret_code, vv, length = pyw.generate_fm_2additive_convex(num, n)
 print( "num: ", num)
 print( "n: ", n)
-print( "array_size: ", array_size)
+print( "ret_code: ", ret_code)
+print( "length of output: ", length)
 print( "vv: ", vv)
 
 # Test wrapper for:
@@ -733,18 +741,35 @@ print( "vv: ", vv)
 # not documented in R or Python user guide
 num = 10
 n = 6
-# array_size, vv = pyw.generate_fm_2additive_convex_withsomeindependent(num, n)
+ret_code = 0
+length = 0
+ret_code, vv, length = pyw.generate_fm_2additive_convex_withsomeindependent(num, n)
 print( "num: ", num)
 print( "n: ", n)
-print( "array_size: ", array_size)
+print( "ret_code: ", ret_code)
+print( "length of output: ", length)
 print( "vv: ", vv)
 
-sys.exit()
+pyw.fm_free( env);
+n = 3
+env = pyw.fm_init( n)
+
+#
+# Here the testing for env_sparse starts
+# 
 
 # Test wrapper for:
 #    void py_prepare_fm_sparse(int n, int tupsize, int* tuples, struct fm_env_sparse* out_env)
-# pyw.prepare_fm_sparse(n, tupsize, tuples, out_env)
-# not documented in R or Python user guide
+n = 3
+tupsize = 0
+env_sparse = pyw.prepare_fm_sparse( n, tupsize)
+
+# Test wrapper for:
+#    void py_free_fm_sparse( struct fm_env_sparse* env)
+pyw.free_fm_sparse( env_sparse)
+
+sys.exit()
+
 
 # Test wrapper for:
 #    int py_tuple_cardinality_sparse(int i, struct fm_env_sparse* env)
@@ -786,6 +811,9 @@ sys.exit()
 # pyw.ChoquetMob_sparse(x, n, env)
 # not documented in R or Python user guide
 
+sys.exit()
+
+
 # Test wrapper for:
 #    void py_ShapleyMob_sparse(double* v, int n, struct fm_env_sparse* out_env)
 # pyw.ShapleyMob_sparse(v, n, out_env)
@@ -856,4 +884,4 @@ sys.exit()
 # pyw.Nonmodularityindex_sparse(w, n, out_env)
 # not documented in R or Python user guide
 
-pyw.fm_free( env);
+
